@@ -24,9 +24,11 @@ except ImportError:
 
 # This kind of built-in overload will have to work.
 
-def len(x):  # @ReservedAssignment
+
+def len(x):
     print("Private built-in called with argument", repr(x))
 
     return _len(x)
 
+
 print("Calling built-in len", len(range(9)))
