@@ -19,6 +19,7 @@ from enum import Enum
 
 print("Enum class with duplicate enumeration values:")
 try:
+
     class Color(Enum):
         red = 1
         green = 2
@@ -26,16 +27,23 @@ try:
         red = 4
 
         print("not allowed to get here")
+
+
 except Exception as e:
     print("Occurred", e)
 
 print("Class variable that conflicts with closure variable:")
+
+
 def testClassNamespaceOverridesClosure():
-        # See #17853.
-        x = 42
-        class X:
-            locals()['x'] = 43
-            y = x
-        print("should be 43:", X.y)
+    # See #17853.
+    x = 42
+
+    class X:
+        locals()["x"] = 43
+        y = x
+
+    print("should be 43:", X.y)
+
 
 testClassNamespaceOverridesClosure()
