@@ -15,7 +15,6 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-
 # In this test we show that return in try/finally executes the finally part
 # just fine.
 
@@ -23,21 +22,27 @@ from __future__ import print_function
 
 import sys
 
+
 def eight():
     return 8
 
+
 def nine():
     return 9
 
+
 def raisy1():
     return 1 / 0
 
+
 def raisy2():
     return 1()
 
+
 def raisy3(arg):
     raise TypeError(arg)
 
+
 def returnInTried(for_call):
     try:
         print("returnInTried with exception info in tried block:", sys.exc_info())
@@ -46,6 +51,7 @@ def returnInTried(for_call):
     finally:
         print("returnInTried with exception info in final block:", sys.exc_info())
 
+
 def returnInFinally(for_call):
     try:
         print("returnInFinally with exception info in tried block:", sys.exc_info())
@@ -54,15 +60,16 @@ def returnInFinally(for_call):
 
         return for_call()
 
+
 print("Standard try finally with return in tried block:")
 print("result", returnInTried(eight))
 
-print('*' * 80)
+print("*" * 80)
 
 print("Standard try finally with return in final block:")
 print("result", returnInFinally(nine))
 
-print('*' * 80)
+print("*" * 80)
 
 print("Exception raising try finally with return in tried block:")
 try:
@@ -70,7 +77,7 @@ try:
 except Exception as e:
     print("Gave exception", repr(e))
 
-print('*' * 80)
+print("*" * 80)
 
 print("Exception raising try finally with return in final block:")
 try:
@@ -78,7 +85,7 @@ try:
 except Exception as e:
     print("Gave exception", repr(e))
 
-print('*' * 80)
+print("*" * 80)
 
 try:
     raisy3("unreal 1")
@@ -91,7 +98,7 @@ except Exception as outer_e:
 
     print("Handler exception remains:", repr(outer_e))
 
-print('*' * 80)
+print("*" * 80)
 
 try:
     raisy3("unreal 2")
@@ -104,4 +111,4 @@ except Exception as outer_e:
 
     print("Handler exception remains:", repr(outer_e))
 
-print('*' * 80)
+print("*" * 80)
