@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,7 +15,6 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-
 print(u"gfcrk")
 print(repr(u"g\xfcrk"))
 
@@ -23,11 +22,13 @@ print(r"""\x00""")
 
 print("\ttest\n")
 
-print("""
+print(
+    """
 something
 with
 new
-lines""")
+lines"""
+)
 
 print(u"favicon.ico (32\xd732)")
 
