@@ -15,8 +15,16 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+""" Test that covers all module attributes. """
+
 from __future__ import print_function
 
+import package_level1.Nearby1
+import package_level1.package_level2.Nearby2
+import package_level1.package_level2.package_level3
+import package_level1.package_level2.package_level3.Nearby3
+
+
 def displayDict(d):
     d = dict(d)
 
@@ -34,12 +42,10 @@ def displayDict(d):
         del d["__compiled__"]
 
     import pprint
+
     return pprint.pformat(d)
 
+
 print(displayDict(globals()))
 
-import package_level1.package_level2.package_level3
-
-import package_level1.Nearby1
-import package_level1.package_level2.Nearby2
-import package_level1.package_level2.package_level3.Nearby3
\ No newline at end of file
+# pylint: disable=unused-import
