@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -24,6 +24,6 @@ print(
     __name__,
     "in",
     __package__
-      if __package__ is not None or sys.version_info[:2] != (3,2) else
-    ".".join(__name__.split(".")[:-1])
+    if __package__ is not None or sys.version_info[:2] != (3, 2)
+    else ".".join(__name__.split(".")[:-1]),
 )
