@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python test originally created or extracted from other peoples work. The
 #     parts from me are licensed as below. It is at least Free Software where
@@ -17,7 +17,9 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-
-
 from win32com import storagecon
 from win32com.shell import shell, shellcon
+
+# nuitka-skip-unless-imports: win32com
+
+print("OK.")
